@@ -38,8 +38,3 @@ class K9Core:
             except (JSONDecodeError, AttributeError) as error:
                 logging.error("Invalid payload: ", r.text)
                 return K9CoreError(message=message,status_code=r.status_code,payload=message)
-           
-
-
-if __name__ == "__main__":
-    print(K9Core().sendRequest(dict(teste1="", teste2=123)))
