@@ -1,6 +1,5 @@
 import logging
 from dataclasses import dataclass
-from datetime import datetime
 import json
 from enum import Enum
 from typing import Generic, List, TypeVar
@@ -56,15 +55,17 @@ class LogMessage(Generic[T]):
     correlation_id: str
     log_level: int
     message: str
+    span_id: str
     # infrastructure: InfraProperties
     # attributes: T
 
     def __str__(self):
         msg = {
             "app_name": self.app_name,
-            "correlation_id": self.correlation_id,
             "log_level": self.log_level,
-            "message": self.message
+            "correlation_id": self.correlation_id,
+            "message": self.message,
+            "span_id": self.span_id
         }
         return f'{msg}'
 
@@ -88,37 +89,35 @@ class K9Logger:
     def __init__(self, app_name: str):
         self.app_name = app_name
 
-    # def __isValidMessage(self, message: str) -> bool:
-    #     for err in self.schema.iter_errors(message):
-    #         print("Teste: ", err)
-    #     return True
-
-    def __get_message(self, message: str, log_level: int, correlation_id: str):
+    def __get_message(self, message: str, log_level: int, correlation_id: str, span_id: str):
         args = {
             "app_name": self.app_name,
-            "correlation_id": correlation_id,
             "log_level": logging.getLevelName(log_level),
-            "message": message
+            "correlation_id": correlation_id,
+            "message": message,
+            "span_id": span_id
         }
 
-        if args["correlation_id"] == '':
-            args["correlation_id"] = str(uuid.uuid4())
-
         return LogMessage(**args)
 
-    def log(self, message: str, log_level: int, correlation_id: str = ''):
-        # self.__isValidMessage(message)
+    def log(self, message, log_level, correlation_id=None, span_id=None):
         msg = self.__get_message(
-            message=message, correlation_id=correlation_id, log_level=log_level)
+            message=message, correlation_id=correlation_id, log_level=log_level, span_id=span_id)
         K9Core().sendRequest(message=json.dumps(msg.__dict__))
         logging.log(level=log_level, msg=msg)
+        
+    def info(self, message, **kwargs):
+        self.log(message, logging.INFO, **kwargs)
+    
+    def error(self, message, **kwargs):
+        self.log(message, logging.ERROR, **kwargs)
+    
+    def debug(self, message, **kwargs):
+        self.log(message, logging.DEBUG, **kwargs)
+        
+    def fatal(self, message, **kwargs):
+        self.log(message, logging.FATAL, **kwargs)
 
-
-if __name__ == "__main__":
-    # attr = Teste(A="", B=432)
-    # infra = InfraProperties(docker_id="", hostname="", ip="", k8s_cluster_name="",
-    #                         k8s_container_id="", k8s_container_name="", k8s_deployment="", k8s_namespace="")
-    # modelTeste = LogMessage[Teste](
-    #     message="", app_name="", correlation_id="", log_level="", timestamp=datetime.utcnow().timestamp())
-    # K9Core().sendRequest(modelTeste)
-    K9Logger(app_name="hello-world").log(log_level=logging.INFO, message="Teste")
+    def warning(self, message, **kwargs):
+        self.log(message, logging.WARNING, **kwargs)
+        
\ No newline at end of file
